import { sendMessage } from '../utils/messaging';
import { createTask, assignTask, completeTask, getPendingTasks } from '../../services/taskService';

export function handleTaskCommand(body: string, sender: string, groupId: string, linkedGroups: Set<string>) {
  if (groupId && linkedGroups.has(groupId)) {
    if (body.startsWith('/tarea')) {
      const command = body.replace('/tarea', '').trim();
      const [action, ...args] = command.split(' ');
      const description = args.join(' ');

      const assignedUserMatch = description.match(/@\w+/);
      const assignedUser = assignedUserMatch ? assignedUserMatch[0] : null;

      const dueDateMatch = description.match(/\d{4}-\d{2}-\d{2}/);
      const dueDate = dueDateMatch ? dueDateMatch[0] : null;

      const cleanDescription = description
        .replace(/@\w+/g, '')
        .replace(/\d{4}-\d{2}-\d{2}/g, '')
        .trim();

      if (action === 'nueva') {
        const finalAssignedUser = assignedUser || `@${sender.split('@')[0]}`;
        const task = createTask(sender, cleanDescription, finalAssignedUser, dueDate);
        sendMessage(sender, `Tarea creada: ${task.id} - ${task.description}${task.assignedTo ? ` asignada a ${task.assignedTo}` : ''}${task.dueDate ? ` para el ${task.dueDate}` : ''}`);
      } else if (action === 'asignar') {
        const taskId = args[0];
        if (assignedUser) {
          assignTask(parseInt(taskId), assignedUser);
          sendMessage(sender, `Tarea ${taskId} asignada a ${assignedUser}`);
        } else {
          sendMessage(sender, 'Debes mencionar a un usuario para asignar la tarea. Ejemplo: /tarea asignar 1 @usuario');
        }
      } else if (action === 'completar') {
        const taskId = args[0];
        completeTask(parseInt(taskId));
        sendMessage(sender, `Tarea ${taskId} marcada como completada`);
      } else if (action === 'mostrar' || !action) {
        // Handle /tarea or /tarea mostrar
        const user = `@${sender.split('@')[0]}`; // Default to the sender
        const tasks = getPendingTasks(user);

        if (tasks.length === 0) {
          sendMessage(sender, 'No tienes tareas pendientes.');
        } else {
          const taskList = tasks.map((task) => {
            return `- Tarea ${task.id}: ${task.description}${task.dueDate ? ` (para el ${task.dueDate})` : ''}`;
          }).join('\n');
          sendMessage(sender, `Tus tareas pendientes:\n${taskList}`);
        }
      } else {
        sendMessage(sender, 'Acción no reconocida. Usa /tarea nueva, /tarea asignar, /tarea completar, o /tarea mostrar.');
      }
    }
  }
}
