import { query, execute } from '../database/db';

// Create a new task
export function createTask(sender: string, description: string, assignedTo?: string, dueDate?: string) {
  const result = execute(
    'INSERT INTO tasks (description, assigned_to, due_date, completed) VALUES (?, ?, ?, ?)',
    [description, assignedTo || null, dueDate || null, false]
  );

  const taskId = result.lastInsertRowid;
  return {
    id: taskId,
    description,
    assignedTo: assignedTo || null,
    dueDate: dueDate || null,
    completed: false,
  };
}

// Assign a task
export function assignTask(taskId: number, assignedTo: string) {
  execute(
    'UPDATE tasks SET assigned_to = ? WHERE id = ?',
    [assignedTo, taskId]
  );
}

// Mark a task as completed
export function completeTask(taskId: number) {
  execute(
    'UPDATE tasks SET completed = TRUE WHERE id = ?',
    [taskId]
  );
}

// Get all tasks (for debugging or future use)
export function getTasks() {
  return query('SELECT * FROM tasks');
}

// Get pending tasks for a specific user
export function getPendingTasks(assignedTo: string) {
  return query(
    'SELECT * FROM tasks WHERE assigned_to = ? AND completed = FALSE',
    [assignedTo]
  );
}
